$title

# Delete versions ${old_version + 1} to $new_version of $page.name Delete version $new_version of $page.name Delete $page.name

Are you sure you want to delete versions ${old_version + 1} to $new_version of this page?
Removing $num_versions versions of the page, which was first modified ${pretty_dateinfo(old_date)} and last modified ${pretty_dateinfo(new_date)}. Are you sure you want to delete version $new_version of this page?
This is the only version of the page, created ${pretty_dateinfo(new_date)}, so the page will be removed completely! Modified ${pretty_dateinfo(new_date)}. Are you sure you want to completely delete this page?
Removing the one and only version of the page, which was created ${pretty_dateinfo(new_date)}. Removing all $num_versions versions of the page, which was created ${pretty_dateinfo(old_date)} and last modified ${pretty_dateinfo(new_date)}.
This is an irreversible operation.